==> nextcloud-23.0.8.tgz: nextcloud/apps/systemtags/l10n/lv.js <==
OC.L10N.register(
    "systemtags",
    {
    "Update" : "Atjaunināt",
    "Create" : "Izveidot",
    "Select tag …" : "Izvēlies birku...",
    "System tag %1$s added by the system" : "Sistēma ir pievienojusi sistēmas birku %1$s",
    "Added system tag {systemtag}" : "Pievienota sistēmas birka {systemtag}",
    "Added system tag %1$s" : "Pievienota sistēmas birka %1$s",
    "%1$s added system tag %2$s" : "%1$s pievienota sistēmas birka %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pievienoja sistēmas birku {systemtag}",
    "Removed system tag {systemtag}" : "Noņemta sistēmas birka {systemtag}",
    "Removed system tag %1$s" : "Noņemta sistēmas birka %1$s",
    "%1$s removed system tag %2$s" : "%1$s noņēma sistēmas birku %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} noņēma sistēmas birku {systemtag}",
    "You created system tag %1$s" : "Jūs izveidojāt sistēmas birku  %1$s",
    "You created system tag {systemtag}" : "Jūs izveidojāt sistēmas birku {systemtag}",
    "%1$s created system tag %2$s" : "%1$s izveidoja sistēmas birku %2$s",
    "{actor} created system tag {systemtag}" : "{actor} izveidoja sistēmas birku {systemtag}",
    "You deleted system tag %1$s" : "Jūs izdzēsāt sistēmas birku %1$s",
    "You deleted system tag {systemtag}" : "Jūs izdzēsāt sistēmas birku {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s izdzēsa sistēmas birku %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izdzēsa sistēmas birku {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atjauninājāt sistēmas birku %2$s uz %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atjauninājāt sistēmas birku {oldsystemtag} uz {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$satjaunināja sistēmas birku %3$s uz %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atjaunināja sistēmas birku {oldsystemtag} uz {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Tu pievienoji sistēmas birku %2$s uz %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pievienojāt sistēmas birku {systemtag} datnei {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$spievienoja sistēmas birku %3$s uz %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pievienoja sistēmas birku {systemtag} {file}",
    "You removed system tag %2$s from %1$s" : "Jūs noņēmāt sistēmas birku %2$s no %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs noņēmāt sistēmas birku {systemtag} no {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s noņēma sistēmas birku %3$s no %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} noņēma sistēmas birku {systemtag} no {file}",
    "%s (restricted)" : "%s (ierobežots)",
    "%s (invisible)" : "%s (neredzams)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistēmas birkas</strong> datnei tikušas mainītas",
    "Tags" : "Birkas",
    "Collaborative tags" : "Sadarbības birkas",
    "Tagged files" : "Atzīmētās datnes",
    "Select tags to filter by" : "Izvēlieties birkas, pēc kurām filtrēt",
    "No tags found" : "Netika atrasta neviena birka",
    "Please select tags to filter by" : "Lūdzu, izvēlieties birkas, pēc kurām filtrēt",
    "No files found for the selected tags" : "Datnes ar atlasītajām birkām netika atrastas",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sadarbības birkas ir pieejamas visiem lietotājiem. Ierobežotās birkas ir redzamas lietotājiem, bet viņi tās nevar piešķirt. Neredzamās birkas ir paredzētas iekšējai lietošanai, jo lietotāji nevar tās redzēt vai piešķirt.",
    "Create a new tag" : "Izveidot jaunu birku",
    "Name" : "Nosaukums",
    "Public" : "Publiska",
    "Restricted" : "Ierobežota",
    "Invisible" : "Neredzama",
    "Delete" : "Dzēst",
    "Reset" : "Atiestatīt",
    "No files in here" : "Šeit nav datņu",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Size" : "Izmērs",
    "Modified" : "Mainīts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/systemtags/l10n/lv.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Sistēma ir pievienojusi sistēmas birku %1$s",
    "Added system tag {systemtag}" : "Pievienota sistēmas birka {systemtag}",
    "Added system tag %1$s" : "Pievienota sistēmas birka %1$s",
    "%1$s added system tag %2$s" : "%1$s pievienota sistēmas birka %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pievienoja sistēmas birku {systemtag}",
    "Removed system tag {systemtag}" : "Noņemta sistēmas birka {systemtag}",
    "Removed system tag %1$s" : "Noņemta sistēmas birka %1$s",
    "%1$s removed system tag %2$s" : "%1$s noņēma sistēmas birku %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} noņēma sistēmas birku {systemtag}",
    "You created system tag %1$s" : "Jūs izveidojāt sistēmas birku  %1$s",
    "You created system tag {systemtag}" : "Jūs izveidojāt sistēmas birku {systemtag}",
    "%1$s created system tag %2$s" : "%1$s izveidoja sistēmas birku %2$s",
    "{actor} created system tag {systemtag}" : "{actor} izveidoja sistēmas birku {systemtag}",
    "You deleted system tag %1$s" : "Jūs izdzēsāt sistēmas birku %1$s",
    "You deleted system tag {systemtag}" : "Jūs izdzēsāt sistēmas birku {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s izdzēsa sistēmas birku %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} izdzēsa sistēmas birku {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atjauninājāt sistēmas birku %2$s uz %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atjauninājāt sistēmas birku {oldsystemtag} uz {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$satjaunināja sistēmas birku %3$s uz %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atjaunināja sistēmas birku {oldsystemtag} uz {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Tu pievienoji sistēmas birku %2$s uz %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pievienojāt sistēmas birku {systemtag} datnei {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$spievienoja sistēmas birku %3$s uz %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pievienoja sistēmas birku {systemtag} {file}",
    "You removed system tag %2$s from %1$s" : "Jūs noņēmāt sistēmas birku %2$s no %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs noņēmāt sistēmas birku {systemtag} no {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s noņēma sistēmas birku %3$s no %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} noņēma sistēmas birku {systemtag} no {file}",
    "%s (restricted)" : "%s (ierobežots)",
    "%s (invisible)" : "%s (neredzams)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistēmas birkas</strong> datnei tikušas mainītas",
    "Tags" : "Birkas",
    "Collaborative tags" : "Sadarbības birkas",
    "Create" : "Izveidot",
    "Update" : "Atjaunināt",
    "Delete" : "Dzēst",
    "Reset" : "Atiestatīt",
    "Public" : "Publiska",
    "Restricted" : "Ierobežota",
    "Invisible" : "Neredzama",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sadarbības birkas ir pieejamas visiem lietotājiem. Ierobežotās birkas ir redzamas lietotājiem, bet viņi tās nevar piešķirt. Neredzamās birkas ir paredzētas iekšējai lietošanai, jo lietotāji nevar tās redzēt vai piešķirt.",
    "No tags found" : "Netika atrasta neviena birka",
    "No files in here" : "Šeit nav datņu",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "Select tag …" : "Izvēlies birku...",
    "Tagged files" : "Atzīmētās datnes",
    "Select tags to filter by" : "Izvēlieties birkas, pēc kurām filtrēt",
    "Please select tags to filter by" : "Lūdzu, izvēlieties birkas, pēc kurām filtrēt",
    "No files found for the selected tags" : "Datnes ar atlasītajām birkām netika atrastas",
    "Create a new tag" : "Izveidot jaunu birku"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
